<?php


namespace App\Http\Controllers;


use App\Helpers\Auther;
use App\Helpers\ErrorHelper;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;

class Auth extends Controller
{
    var $errors = null;
    function __construct()
    {
        $this->errors = new ErrorHelper();
    }

    function auth(Request $request){
        if(!$request->input('login')){
            $this->errors->report(1005);
        }
        if(!$request->input('password')){
            $this->errors->report(1006);
        }
        $user = User::where('login', $request->input('login'))->first();
        if(empty($user)){
            $this->errors->report(1007);
        }
        else{
            if(!Hash::check($request->input('password'), $user->password)){
                $this->errors->report(1007);
            }
            if($user->token_expired<time()){
                $new_token = Hash::make($user->login.time());
                User::where('id', $user->id)->update(['token'=>$new_token, 'token_expired'=>time()+3600]);
                return ['id'=>$user->id, 'token'=>$new_token];
            }
            return ['id'=>$user->id, 'token'=>$user->token];
        }
        if($this->errors->hasErrors()){
            return $this->errors->render();
        }
    }

    function register(Request $request){
        if(!Auther::isAuth($request)){
            $this->errors->report(2001);
        }
        if(!$request->input('login')){
            $this->errors->report(1001);
        }
        if(!$request->input('password')){
            $this->errors->report(1002);
        }
        if(!$request->input('email')){
            $this->errors->report(1003);
        }
        if($this->errors->hasErrors()){
            return $this->errors->render();
        }
        $exists = User::where('login', $request->input('login'))->orWhere('email', $request->input('email'))->first();
        $success = false;
        if($exists){
            $this->errors->report(1004);
        }
        else{
            $success = User::insert(['login'=>$request->input('login'),
                                'password'=>Hash::make($request->input('password')),
                                'email'=>$request->input('email'),
                                'token'=>Hash::make($request->input('login').time()),
                                'token_expired'=>time() + 3600
                                ]);
            if(!$success){
                $this->errors->report();
            }
        }

        if($this->errors->hasErrors()){
            return $this->errors->render();
        }
        return ['status'=>'ok'];
    }
}